/* BdfServer_Html - Copyright (c) 2010-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.html.forms;

import fr.exemole.bdfserver.api.ficheform.AddendaIncludeElement;
import fr.exemole.bdfserver.api.ficheform.AlbumIncludeElement;
import fr.exemole.bdfserver.api.ficheform.CorpusIncludeElement;
import fr.exemole.bdfserver.api.ficheform.FormElement;
import fr.exemole.bdfserver.api.ficheform.GeopointProprieteSubfieldsElement;
import fr.exemole.bdfserver.api.ficheform.HiddenFieldElement;
import fr.exemole.bdfserver.api.ficheform.HiddenIncludeElement;
import fr.exemole.bdfserver.api.ficheform.ImageProprieteSubfieldsElement;
import fr.exemole.bdfserver.api.ficheform.ItemFieldElement;
import fr.exemole.bdfserver.api.ficheform.LangFieldElement;
import fr.exemole.bdfserver.api.ficheform.MontantInformationSubfieldsElement;
import fr.exemole.bdfserver.api.ficheform.MontantProprieteSubfieldsElement;
import fr.exemole.bdfserver.api.ficheform.PersonneProprieteSubfieldsElement;
import fr.exemole.bdfserver.api.ficheform.RattachementElement;
import fr.exemole.bdfserver.api.ficheform.TextFieldElement;
import fr.exemole.bdfserver.api.ficheform.ThesaurusIncludeElement;
import fr.exemole.bdfserver.api.namespaces.FicheFormSpace;
import fr.exemole.bdfserver.api.ui.options.InputOption;
import net.mapeadores.util.attr.Attribute;
import net.mapeadores.util.attr.Attributes;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.HtmlAttributes;
import net.mapeadores.util.html.HtmlPrinter;
import net.mapeadores.util.localisation.Lang;


/**
 *
 * @author Vincent Calame
 */
public final class CommonFormHtml {

    private CommonFormHtml() {
    }

    public static boolean printFormElement(HtmlPrinter hp, FormElement formElement, FormParameters formParameters) {
        if (formElement instanceof TextFieldElement) {
            CorpusFieldFormHtml.printTextField(hp, (TextFieldElement) formElement, formParameters);
        } else if (formElement instanceof LangFieldElement) {
            CorpusFieldFormHtml.printLangField(hp, (LangFieldElement) formElement, formParameters);
        } else if (formElement instanceof PersonneProprieteSubfieldsElement) {
            CorpusFieldFormHtml.printPersonneProprieteSubfields(hp, (PersonneProprieteSubfieldsElement) formElement, formParameters);
        } else if (formElement instanceof GeopointProprieteSubfieldsElement) {
            CorpusFieldFormHtml.printGeopointProprieteSubfields(hp, (GeopointProprieteSubfieldsElement) formElement, formParameters);
        } else if (formElement instanceof MontantProprieteSubfieldsElement) {
            CorpusFieldFormHtml.printMontantProprieteSubfields(hp, (MontantProprieteSubfieldsElement) formElement, formParameters);
        } else if (formElement instanceof MontantInformationSubfieldsElement) {
            CorpusFieldFormHtml.printMontantInformationSubfields(hp, (MontantInformationSubfieldsElement) formElement, formParameters);
        } else if (formElement instanceof ItemFieldElement) {
            CorpusFieldFormHtml.printItemField(hp, (ItemFieldElement) formElement, formParameters);
        } else if (formElement instanceof HiddenFieldElement) {
            CorpusFieldFormHtml.printHiddenField(hp, (HiddenFieldElement) formElement, formParameters);
        } else if (formElement instanceof ImageProprieteSubfieldsElement) {
            CorpusFieldFormHtml.printImageProprieteSubfields(hp, (ImageProprieteSubfieldsElement) formElement, formParameters);
        } else if (formElement instanceof RattachementElement) {
            IncludeFormHtml.printRattachement(hp, (RattachementElement) formElement, formParameters);
        } else if (formElement instanceof ThesaurusIncludeElement.Text) {
            IncludeFormHtml.printTextThesaurusInclude(hp, (ThesaurusIncludeElement.Text) formElement, formParameters);
        } else if (formElement instanceof ThesaurusIncludeElement.List) {
            IncludeFormHtml.printListThesaurusInclude(hp, (ThesaurusIncludeElement.List) formElement, formParameters);
        } else if (formElement instanceof HiddenIncludeElement) {
            IncludeFormHtml.printHiddenInclude(hp, (HiddenIncludeElement) formElement, formParameters);
        } else if (formElement instanceof ThesaurusIncludeElement.NotEditable) {
            IncludeFormHtml.printNotEditableThesaurusInclude(hp, (ThesaurusIncludeElement.NotEditable) formElement, formParameters);
        } else if (formElement instanceof ThesaurusIncludeElement.FicheStyle) {
            IncludeFormHtml.printFicheStyleThesaurusInclude(hp, (ThesaurusIncludeElement.FicheStyle) formElement, formParameters);
        } else if (formElement instanceof CorpusIncludeElement) {
            IncludeFormHtml.printCorpusInclude(hp, (CorpusIncludeElement) formElement, formParameters);
        } else if (formElement instanceof AlbumIncludeElement) {
            IncludeFormHtml.printAlbumInclude(hp, (AlbumIncludeElement) formElement, formParameters, false);
        } else if (formElement instanceof AddendaIncludeElement) {
            IncludeFormHtml.printAddendaInclude(hp, (AddendaIncludeElement) formElement, formParameters, false);
        } else {
            return false;
        }
        return true;
    }

    public static int getDefaultSize(String widthType) {
        switch (widthType) {
            case InputOption.WIDTH_SMALL:
                return 21;
            case InputOption.WIDTH_MEDIUM:
                return 39;
            case InputOption.WIDTH_LARGE:
                return 77;
            default:
                return 50;
        }
    }

    public static HtmlAttributes addClasses(HtmlAttributes attrs, Attributes attributes) {
        Attribute attribute = attributes.getAttribute(FicheFormSpace.CLASSES_KEY);
        if (attribute != null) {
            for (String value : attribute) {
                attrs.addClass(value);
            }
        }
        return attrs;
    }

    public static HtmlAttributes addTextInputAttributes(HtmlAttributes inputAttrs, Attributes attributes, Lang lang) {
        Attribute placeholderAttribute = attributes.getAttribute(FicheFormSpace.getPlaceholderAttributeKey(lang));
        Attribute maxlengthAttribute = attributes.getAttribute(FicheFormSpace.MAXLENGTH_KEY);
        int maxLength = -1;
        String placeholder = (placeholderAttribute != null) ? toString(placeholderAttribute) : null;
        if (maxlengthAttribute != null) {
            try {
                maxLength = Integer.parseInt(maxlengthAttribute.getFirstValue());
            } catch (NumberFormatException nfe) {

            }
        }
        return inputAttrs
                .attr((placeholder != null), "placeholder", placeholder)
                .attr((maxLength > 0), "maxlength", String.valueOf(maxLength));
    }

    private static String toString(Attribute attribute) {
        if (attribute.size() == 1) {
            return attribute.getFirstValue();
        } else {
            StringBuilder buf = new StringBuilder();
            for (String value : attribute) {
                if (buf.length() > 0) {
                    buf.append('\n');
                }
                buf.append(value);
            }
            return buf.toString();
        }
    }

    public static boolean printStandardLabel(HtmlPrinter hp, FormElement formElement, Lang lang, String inputId) {
        HtmlAttributes labelAttrs = HA.forId(inputId).attr("data-ficheform-role", "label").classes("ficheform-standard-Label");
        addTooltip(labelAttrs, formElement.getAttributes(), lang);
        hp
                .__breakLine()
                .LABEL(labelAttrs)
                .__escape(formElement.getLabel())
                ._LABEL()
                .__breakLine()
                .SPAN("ficheform-standard-Colon")
                .__escape(':')
                ._SPAN()
                .__breakLine();
        return true;
    }

    public static HtmlAttributes addTooltip(HtmlAttributes attrs, Attributes attributes, Lang lang) {
        Attribute tooltipAttribute = attributes.getAttribute(FicheFormSpace.getTooltipAttributeKey(lang));
        String tooltip = (tooltipAttribute != null) ? toString(tooltipAttribute) : null;
        return attrs
                .attr((tooltip != null), "data-tooltip", tooltip);
    }

}
